# CHATBOT
___
Chatbot іs a personal assistant.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install Chatbot-by-IE
```

## Description

* AddressBook
* NoteBook
* Sort files
* Games


## Command to start from Terminal

### /> chatbot


## License

[MIT](https://choosealicense.com/licenses/mit/)